@@ -15,6 +15,10 @@ day_html_header = """<html lang="zh-cn">
             font-size: large;
             color: #0d7eff;
         }
+        div {
+            display: table;
+            margin: auto;
+        }
     </style>
 </header>
 """
@@ -31,6 +35,10 @@ day_html_body = """<body>
 </body>
 </html>"""
 
+match_brief_body = """<body><div>{body}</div></body></html>"""
+match_brief_today = """<tr><th width="80px">结果ID</th><th width="240px" bgcolor=#FAEBD7>对战双方</th></tr>"""
+match_brief_tomorrow = """<tr><th width="80px">比赛时间</th><th width="240px" bgcolor=#FAEBD7>对战双方</th></tr>"""
+
 
 def day_analyze_builder(date: str, inf: dict) -> str:
     """
@@ -48,6 +56,15 @@ def day_analyze_builder(date: str, inf: dict) -> str:
     return day_html_header + day_html_body.format(caption=f"---{date}---", body=_msg)
 
 
+def match_brief_builder(msg: dict) -> str:
+    html = ""
+    if msg["j"]:
+        html += f"""<table border="1"><caption><b>今日赛报</b></caption>{match_brief_today}{msg["j"]}</table>"""
+    if msg["m"]:
+        html += f"""<table border="1"><caption><b>明日赛程</b></caption>{match_brief_tomorrow}{msg["m"]}</table>"""
+    return day_html_header + match_brief_body.format(body=html)
+
+
 class DayAnalyze:
     pass
 
